Skip to content
KitploitKITPLOIT
ToolsExploitsBlog
Log in
Einreichen
ToolsExploitsBlog
Einreichen

Hacking-, PenTest- und Cybersicherheits-Tools für Ihr Sicherheitsarsenal!

Kitploit ist ein Verzeichnis von Hacking-, Cybersicherheits- und Pentesting-Tools. Entdecken Sie die neuesten Projekt-Updates, um Schwachstellen zu finden, Systeme zu analysieren, Tests zu automatisieren und Ihre Sicherheit zu stärken.

··Feeds·Kontakt·Datenschutz·© 2026 Kitploit

Tool-Verzeichnis

Kategorien

Alle Kategorien anzeigen
Loading categories
mapcidr — Dienstprogramm zur Durchführung mehrerer Operationen für bestimmte Subnetz-/CIDR-Bereiche. | Kitploit
Tools/GitHubGitHub/projectdiscovery/mapcidr
AufklärungNetzwerkkartierungInformationsbeschaffungDienstprogramme & Frameworks
GitHubprojectdiscovery/mapcidr

mapcidr

Dienstprogramm zur Durchführung mehrerer Operationen für bestimmte Subnetz-/CIDR-Bereiche.

Repository anzeigen
1.2k11177vor 13h 59mVon Kitploit geprüft

Beliebteste

Alle anzeigen →

Entdecken Sie die meistgenutzten Tools unserer Community.

Alle Tools erkunden

Durchsuchen Sie unsere Tool-Sammlung

Alle Tools anzeigen →
Teilen
Webseite

mapCIDR

Ein Dienstprogramm zur Durchführung mehrerer Operationen für ein gegebenes Subnetz/CIDR-Bereich.

Funktionen • Installation • Verwendung • Bibliothek • Discord beitreten


mapCIDR wurde entwickelt, um die Lastverteilung für Massenscan-Operationen zu erleichtern; es kann sowohl als Bibliothek als auch als eigenständiges CLI-Tool verwendet werden.

Funktionen

mapCIDR

  • CIDR-Erweiterung wird unterstützt (Standard)
  • CIDR-Aufteilung wird unterstützt (sbh, sbc)
  • CIDR/IP-Zusammenfassung wird unterstützt (a, aa)
  • CIDR/IP-Abgleich wird unterstützt (match-ip)
  • CIDR/IP-Filter wird unterstützt (filter-ip)
  • CIDR/IP-Sortierung wird unterstützt (s, sr)
  • CIDR-Hostzählung wird unterstützt (count)
  • Mehrere IP-Formate werden unterstützt (ip-format)
  • IP/PORT-Mischung wird unterstützt (si, sp)
  • IPv4/IPv6-Konvertierung wird unterstützt (t4, t6)
  • CIDR-STDIN (Pipe)-Eingabe wird unterstützt

Installation

go install -v github.com/projectdiscovery/mapcidr/cmd/mapcidr@latest

Verwendung

mapcidr -h

Dies zeigt die Hilfe für das Tool an. Hier sind alle unterstützten Schalter.

EINGABE:
   -cl, -cidr string[]  CIDR/IP/Datei mit einer Liste von CIDR/IP, die verarbeitet werden sollen

VERARBEITUNG:
   -sbc int                  CIDR nach angegebener CIDR-Anzahl aufteilen
   -sbh int                  CIDR nach angegebener HOST-Anzahl aufteilen
   -a, -aggregate            IPs/CIDRs in das kleinste Subnetz zusammenfassen
   -aa, -aggregate-approx    Spärliche IPs/CIDRs in das kleinste approximierte Subnetz zusammenfassen
   -c, -count                Anzahl der IPs im angegebenen CIDR zählen
   -t4, -to-ipv4             IPs in das IPv4-Format konvertieren
   -t6, -to-ipv6             IPs in das IPv6-Format konvertieren
   -ip-format, -if string[]  IP-Formate (0,1,2,3,4,5,6,7,8,9,10,11)
   -zpn, -zero-pad-n int     Anzahl der zu verwendenden aufgefüllten Nullen (Standard: 3)
   -zpp, -zero-pad-permute   Permutationen von 0 bis zero-pad-n für jedes Oktett aktivieren

FILTER:
   -f4, -filter-ipv4         IPv4-IPs aus der Eingabe filtern
   -f6, -filter-ipv6         IPv6-IPs aus der Eingabe filtern
   -skip-base                Basis-IPs (endend auf .0) in der Ausgabe überspringen
   -skip-broadcast           Broadcast-IPs (endend auf .255) in der Ausgabe überspringen
   -mi, -match-ip string[]   IP/CIDR/DATEI mit einer Liste von IP/CIDR zum Abgleichen (kommasepariert, Dateieingabe)
   -fi, -filter-ip string[]  IP/CIDR/DATEI mit einer Liste von IP/CIDR zum Filtern (kommasepariert, Dateieingabe)

VERSCHIEDENES:
   -s, -sort                  Eingabe-IPs/CIDRs in aufsteigender Reihenfolge sortieren
   -sr, -sort-reverse         Eingabe-IPs/CIDRs in absteigender Reihenfolge sortieren
   -si, -shuffle-ip           Eingabe-IPs in zufälliger Reihenfolge mischen
   -sp, -shuffle-port string  Eingabe-IP:Port in zufälliger Reihenfolge mischen

AKTUALISIERUNG:
   -up, -update                 mapcidr auf die neueste Version aktualisieren
   -duc, -disable-update-check  automatische Überprüfung auf mapcidr-Updates deaktivieren
   
AUSGABE:
   -verbose            Ausführlicher Modus
   -o, -output string  Datei, in die die Ausgabe geschrieben werden soll
   -silent             Stiller Modus
   -version            Version des Projekts anzeigen

mapCIDR ausführen

Um eine Liste von IPs für ein bestimmtes CIDR zu erhalten, verwenden Sie den folgenden Befehl:

CIDR-Erweiterung

mapcidr -cidr 173.0.84.0/24
                   ____________  ___    
  __ _  ___ ____  / ___/  _/ _ \/ _ \
 /  ' \/ _ '/ _ \/ /___/ // // / , _/   
/_/_/_/\_,_/ .__/\___/___/____/_/|_| v0.5
          /_/                                                     	 

		projectdiscovery.io

[WRN] Mit Vorsicht verwenden. Sie sind für Ihre Handlungen verantwortlich
[WRN] Die Entwickler übernehmen keine Haftung und sind nicht verantwortlich für Missbrauch oder Schäden.

173.0.84.0
173.0.84.1
173.0.84.2
173.0.84.3
173.0.84.4
173.0.84.5
173.0.84.13
173.0.84.14
173.0.84.15
173.0.84.16

Es ist auch möglich, eine Liste von IPs für einen bestimmten IP-Bereich mit dem folgenden Befehl zu erhalten:

$ echo "192.168.0.0-192.168.0.5" | mapcidr
192.168.0.0
192.168.0.1
192.168.0.2
192.168.0.3
192.168.0.4
192.168.0.5

CIDR-Aufteilung nach CIDR-Anzahl

Um ein bestimmtes CIDR oder eine Liste von CIDRs nach CIDR-Anzahl aufzuteilen oder in mehrere gleich große kleinere Subnetze zu unterteilen, verwenden Sie den folgenden Befehl:

mapcidr -cidr 173.0.84.0/24 -sbc 10 -silent
173.0.84.0/27
173.0.84.32/27
173.0.84.64/27
173.0.84.96/27
173.0.84.128/27
173.0.84.160/27
173.0.84.208/28
173.0.84.192/28
173.0.84.240/28
173.0.84.224/28

CIDR-Aufteilung nach HOST-Anzahl

Um das angegebene CIDR für eine gleiche Anzahl von Hosts in jedem CIDR aufzuteilen, verwenden Sie den folgenden Befehl:

mapcidr -cidr 173.0.84.0/16 -sbh 20000 -silent
173.0.0.0/18
173.0.64.0/18
173.0.128.0/18
173.0.192.0/18

Hinweis: Eine perfekte Aufteilung ist nur möglich, wenn die gewünschte Anzahl von Teilen oder Hosts pro Subnetz eine Zweierpotenz ist. Andernfalls versucht das Tool automatisch, die beste Aufteilungsstrategie zu finden, um das gewünschte Ergebnis zu erzielen.

CIDR/IP-Zusammenfassung

Um mehrere CIDR-Bereiche zu einem kleineren Subnetzblock zusammenzufassen, verwenden Sie den folgenden Befehl:

$ mapcidr -cl cidrs.txt -aggregate

Um CIDR-Blöcke für eine bestimmte Liste von IPs aufzulisten, verwenden Sie den folgenden Befehl:

$ mapcidr -il ips.txt -aggregate

Es ist auch möglich, approximierte Zusammenfassungen für spärliche IP-Gruppen (nur Version 4) durchzuführen. Das endgültige Intervall enthält zusammenhängende IPs, die nicht zur Eingabe gehören:

$ cat ips.txt 

1.1.1.1
1.1.1.16
1.1.1.31
$ cat ips.txt | mapcidr -aggregate-approx

1.1.1.0/27

Um CIDR-Blöcke für einen bestimmten IP-Bereich (IPv4 | IPv6) aufzulisten, verwenden Sie den folgenden Befehl:

 $ mapcidr  -cl 192.168.0.1-192.168.0.255 -aggregate
 ODER
 $ echo 192.168.0.1-192.168.0.255 | mapcidr -aggregate
192.168.0.1/32
192.168.0.2/31
192.168.0.4/30
192.168.0.8/29
192.168.0.16/28
192.168.0.32/27
192.168.0.64/26
192.168.0.128/25

IPs aus CIDR abgleichen / filtern

Um IPs aus der angegebenen Liste von CIDR-Bereichen abzugleichen, verwenden Sie den folgenden Befehl:

$ mapcidr -cidr 192.168.1.0/24 -mi 192.168.1.253,192.168.1.252
$ mapcidr -cidr 192.168.1.0/24 -mi ip_list_to_match.txt
Tool herunterladen